@@ -54,7 +54,7 @@ foreach ($this->rows as $row)
 
 	$name = Lang::txt('PLG_MEMBERS_ACTIVITY_ANONYMOUS');
 
-	if (!$this->row->log->get('anonymous'))
+	if (!$row->log->get('anonymous'))
 	{
 		$creator = User::getInstance($row->log->get('created_by'));
 		$name = $this->escape(stripslashes($creator->get('name', Lang::txt('PLG_MEMBERS_ACTIVITY_UNKNOWN'))));
